
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route, Navigate } from "react-router-dom";
import { AuthProvider } from "@/contexts/AuthContext";
import { AdminAuthProvider } from "@/contexts/AdminAuthContext";
import { ModalProvider } from "@/contexts/ModalContext";
import { useAnalytics } from "@/hooks/useAnalytics";
import ProtectedRoute from "@/components/ProtectedRoute";
import PublicAuthRoute from "@/components/PublicAuthRoute";
import AdminRoute from "@/components/AdminRoute";
import CreatorRoute from "@/components/hotspota/CreatorRoute";
import ProfileRedirect from "@/components/ProfileRedirect";
import { CookieConsentBanner } from "@/components/CookieConsentBanner";
import DemoAuthPrompt from "@/components/DemoAuthPrompt";
import Index from "./pages/Index";
import OptimizedLanding from "./pages/OptimizedLanding";
import AdminAuth from "./pages/AdminAuth";
import Login from "./pages/Login";
import Activate from "./pages/Activate";
import JumpToLocation from "./pages/JumpToLocation";
import UploadPage from "./pages/Upload";
import DemoMap from "./pages/DemoMap";
import DemoFeed from "./pages/DemoFeed";
import DemoBrowse from "./pages/DemoBrowse";
import DemoWallet from "./pages/DemoWallet";
import DemoProfile from "./pages/DemoProfile";
import DemoSettings from "./pages/DemoSettings";
import Journal from "./pages/Journal";
import BlogPost from "./pages/BlogPost";
import NotFound from "./pages/NotFound";
import ResetPassword from "./pages/ResetPassword";
import Roadmap from "./pages/Roadmap";
import HotspotaLanding from "./pages/HotspotaLanding";

import HotspotaSettings from "./pages/HotspotaSettings";
import Privacy from "./pages/Privacy";
import AdminMedia from "./pages/AdminMedia";
import CreatorToolsBlogPost from "./pages/CreatorToolsBlogPost";
import AtlasDashboard from "./pages/AtlasDashboard";
import AtlasViewer from "./pages/AtlasViewer";
import ScratchMapPage from "./pages/ScratchMapPage";
import AuthenticatedHome from "./components/AuthenticatedHome";
import { usePerformance } from "@/hooks/usePerformance";
import { 
  LazyAdmin, 
  LazyAnalytics, 
  LazyBrowse, 
  LazyFeed, 
  LazyProfile, 
  LazySettings, 
  LazyWallet, 
  LazyHotspota, 
  LazyHotspotaDashboard,
  LazyMap,
  LazyNewMap
} from "./components/LazyRoute";

const queryClient = new QueryClient();

const AppContent = () => {
  // Initialize analytics globally for all interactions
  const analytics = useAnalytics();
  
  // Initialize performance monitoring
  const performance = usePerformance();
  
  return (
    <Routes>
      <Route path="/" element={<AuthenticatedHome />} />
      <Route path="/landing" element={<Index />} />
      <Route path="/landing-optimized" element={<OptimizedLanding />} />
      <Route path="/roadmap" element={<Roadmap />} />
      <Route path="/hotspota-landing" element={<HotspotaLanding />} />
      
      <Route path="/login" element={
        <>
          <Login />
          <DemoAuthPrompt />
        </>
      } />
      <Route path="/activate" element={<ProtectedRoute><Activate /></ProtectedRoute>} />
      <Route path="/reset-password" element={<ResetPassword />} />
      <Route path="/journal" element={<Journal />} />
      <Route path="/journal/:slug" element={<BlogPost />} />
      <Route path="/journal/creator-tools-hotspottah-spottah-me" element={<CreatorToolsBlogPost />} />
      <Route path="/map" element={
        <PublicAuthRoute>
          <LazyMap />
        </PublicAuthRoute>
      } />
      <Route path="/new-map" element={
        <PublicAuthRoute>
          <LazyNewMap />
        </PublicAuthRoute>
      } />
      <Route path="/jump-to-location" element={<JumpToLocation />} />
      <Route path="/demo-map" element={<DemoMap />} />
      <Route path="/demo-feed" element={<DemoFeed />} />
      <Route path="/demo-browse" element={<DemoBrowse />} />
      <Route path="/demo-wallet" element={<DemoWallet />} />
      <Route path="/demo-profile" element={<DemoProfile />} />
      <Route path="/demo-settings" element={<DemoSettings />} />
      <Route path="/browse" element={
        <PublicAuthRoute>
          <LazyBrowse />
        </PublicAuthRoute>
      } />
      <Route path="/feed" element={
        <PublicAuthRoute>
          <LazyFeed />
        </PublicAuthRoute>
      } />
      <Route 
        path="/upload" 
        element={
          <PublicAuthRoute>
            <UploadPage />
          </PublicAuthRoute>
        } 
      />
      <Route 
        path="/settings" 
        element={
          <PublicAuthRoute>
            <LazySettings />
          </PublicAuthRoute>
        } 
      />
      <Route 
        path="/wallet" 
        element={
          <PublicAuthRoute>
            <LazyWallet />
          </PublicAuthRoute>
        } 
      />
      <Route 
        path="/profile/me" 
        element={
          <PublicAuthRoute>
            <ProfileRedirect />
          </PublicAuthRoute>
        } 
      />
       <Route 
         path="/profile/:username" 
         element={<LazyProfile />} 
       />
       
       {/* Scratch Map Route */}
       <Route 
         path="/scratch-map" 
         element={
           <PublicAuthRoute>
             <ScratchMapPage />
           </PublicAuthRoute>
         } 
       />
       
       {/* Atlas Routes */}
      <Route 
        path="/atlas/dashboard" 
        element={
          <PublicAuthRoute>
            <AtlasDashboard />
          </PublicAuthRoute>
        } 
      />
      <Route 
        path="/atlas/:slug" 
        element={<AtlasViewer />} 
      />
      
      {/* Hotspota Routes */}
      <Route 
        path="/hotspota" 
        element={
          <CreatorRoute>
            <LazyHotspota />
          </CreatorRoute>
        } 
      />
      <Route 
        path="/hotspota/dashboard" 
        element={
          <CreatorRoute>
            <LazyHotspotaDashboard />
          </CreatorRoute>
        } 
      />
      <Route 
        path="/hotspota/settings" 
        element={
          <CreatorRoute>
            <HotspotaSettings />
          </CreatorRoute>
        } 
      />
      <Route 
        path="/admin" 
        element={
          <AdminAuthProvider>
            <AdminRoute>
              <LazyAdmin />
            </AdminRoute>
          </AdminAuthProvider>
        } 
      />
      <Route 
        path="/analytics" 
        element={
          <AdminAuthProvider>
            <AdminRoute>
              <LazyAnalytics />
            </AdminRoute>
          </AdminAuthProvider>
        } 
      />
      <Route 
        path="/admin/media" 
        element={
          <AdminAuthProvider>
            <AdminRoute>
              <AdminMedia />
            </AdminRoute>
          </AdminAuthProvider>
        } 
      />
      <Route path="/privacy" element={<Privacy />} />
      <Route path="/admin-auth" element={
        <AdminAuthProvider>
          <AdminAuth />
        </AdminAuthProvider>
      } />
      {/* Legacy redirect for old auth route */}
      <Route path="/auth" element={<Navigate to="/login" replace />} />
      <Route path="*" element={<NotFound />} />
    </Routes>
  );
};

const App = () => (
  <QueryClientProvider client={queryClient}>
    <TooltipProvider>
      <Toaster />
      <Sonner />
      <BrowserRouter>
        <AuthProvider>
          <ModalProvider>
            <AppContent />
            <CookieConsentBanner />
          </ModalProvider>
        </AuthProvider>
      </BrowserRouter>
    </TooltipProvider>
  </QueryClientProvider>
);

export default App;
